# coding: utf-8

"""
    Visier Data In APIs

    Visier APIs for sending data to Visier and running data load jobs.

    The version of the OpenAPI document: 22222222.99201.1614
    Contact: alpine@visier.com

    Please note that this SDK is currently in beta.
    Functionality and behavior may change in future releases.
    We encourage you to provide feedback and report any issues encountered during your use.
"""  # noqa: E501


import unittest

import visier_api_data_in.models
from visier_api_data_in.models.assign_connector_credentials_response_dto import AssignConnectorCredentialsResponseDTO

class TestAssignConnectorCredentialsResponseDTO(unittest.TestCase):
    """AssignConnectorCredentialsResponseDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AssignConnectorCredentialsResponseDTO:
        """Test AssignConnectorCredentialsResponseDTO
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """

        if include_optional:
            return AssignConnectorCredentialsResponseDTO(
                tenants = [
                    visier_api_data_in.models.assign_connector_credentials_by_tenant_response_dto.AssignConnectorCredentialsByTenantResponseDTO(
                        connectors = [
                            visier_api_data_in.models.assign_connector_with_credentials_response_dto.AssignConnectorWithCredentialsResponseDTO(
                                connector = None, 
                                credential = None, )
                            ], 
                        message = '', 
                        status = 'Unknown', 
                        tenant_code = '', )
                    ]
            )
        else:
            return AssignConnectorCredentialsResponseDTO(
        )

    def testAssignConnectorCredentialsResponseDTO(self):
        """Test AssignConnectorCredentialsResponseDTO"""
        def validate_instance(instance):
            AssignConnectorCredentialsResponseDTO.model_validate(inst_req_only)
            instance_deserialized = AssignConnectorCredentialsResponseDTO.from_dict(instance.to_dict())
            assert instance == instance_deserialized

        inst_req_only = self.make_instance(include_optional=False)
        validate_instance(inst_req_only)

        inst_req_and_optional = self.make_instance(include_optional=True)
        validate_instance(inst_req_and_optional)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Visier Data In APIs

    Visier APIs for sending data to Visier and running data load jobs.

    The version of the OpenAPI document: 22222222.99201.1614
    Contact: alpine@visier.com

    Please note that this SDK is currently in beta.
    Functionality and behavior may change in future releases.
    We encourage you to provide feedback and report any issues encountered during your use.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt
from typing import Any, ClassVar, Dict, List, Optional
from visier_api_data_in.models.plan_data_load_change_list_dto import PlanDataLoadChangeListDTO
from visier_api_data_in.models.plan_data_load_error_dto import PlanDataLoadErrorDTO
from typing import Optional, Set
from typing_extensions import Self

class PlanDataUploadResponseDTO(BaseModel):
    """
    PlanDataUploadResponseDTO
    """ # noqa: E501
    changelists: Optional[List[PlanDataLoadChangeListDTO]] = Field(default=None, description="The collection of changes grouped by plan item made during the data load process. This list only contains the changes specified by the load. If you indicated in the request that the changes are to be rolled up or distributed, the values modified as a result of the calculations are not listed here.")
    errors: Optional[List[PlanDataLoadErrorDTO]] = Field(default=None, description="The collection of errors encountered during the data load process.")
    potential_updated_cells_count: Optional[StrictInt] = Field(default=None, description="The number of cells that would have been updated if all changes were saved.", alias="potentialUpdatedCellsCount")
    updated_cells_count: Optional[StrictInt] = Field(default=None, description="The number of cells that were updated from the data load process.", alias="updatedCellsCount")
    __properties: ClassVar[List[str]] = ["changelists", "errors", "potentialUpdatedCellsCount", "updatedCellsCount"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PlanDataUploadResponseDTO from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in changelists (list)
        _items = []
        if self.changelists:
            for _item_changelists in self.changelists:
                if _item_changelists:
                    _items.append(_item_changelists.to_dict())
            _dict['changelists'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in errors (list)
        _items = []
        if self.errors:
            for _item_errors in self.errors:
                if _item_errors:
                    _items.append(_item_errors.to_dict())
            _dict['errors'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PlanDataUploadResponseDTO from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "changelists": [PlanDataLoadChangeListDTO.from_dict(_item) for _item in obj["changelists"]] if obj.get("changelists") is not None else None,
            "errors": [PlanDataLoadErrorDTO.from_dict(_item) for _item in obj["errors"]] if obj.get("errors") is not None else None,
            "potentialUpdatedCellsCount": obj.get("potentialUpdatedCellsCount"),
            "updatedCellsCount": obj.get("updatedCellsCount")
        })
        return _obj





# coding: utf-8

"""
    Visier Data In APIs

    Visier APIs for sending data to Visier and running data load jobs.

    The version of the OpenAPI document: 22222222.99201.1614
    Contact: alpine@visier.com

    Please note that this SDK is currently in beta.
    Functionality and behavior may change in future releases.
    We encourage you to provide feedback and report any issues encountered during your use.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class ExtractDataAndLoadDTO(BaseModel):
    """
    ExtractDataAndLoadDTO
    """ # noqa: E501
    all_tenants: Optional[StrictBool] = Field(default=None, description="If \"true\", runs an extraction job for all tenants and ignores the tenants field.", alias="allTenants")
    batch_size_override: Optional[StrictInt] = Field(default=None, description="The maximum amount of IDs the job can retrieve in each batch.", alias="batchSizeOverride")
    connector_ids: Optional[List[StrictStr]] = Field(default=None, description="The unique IDs of the connectors to run extraction jobs for.", alias="connectorIds")
    data_category_id: Optional[StrictStr] = Field(default=None, description="The unique ID of the data category in which to generate objects.", alias="dataCategoryId")
    disable_artifact_generation: Optional[StrictBool] = Field(default=None, description="If \"true\", doesn't generate objects after the extraction jobs succeeds.", alias="disableArtifactGeneration")
    excluded_tenants: Optional[List[StrictStr]] = Field(default=None, description="The unique IDs of the tenants to exclude from the extraction job. Only valid if `allTenants` is \"true\".", alias="excludedTenants")
    extract_to_time_override: Optional[StrictStr] = Field(default=None, description="An epoch timestamp in milliseconds for the end time up to which to retrieve data.", alias="extractToTimeOverride")
    force_update_existing_artifacts: Optional[StrictBool] = Field(default=None, description="If \"true\" and `disableArtifactGeneration` is \"false\", updates extractor artifacts, which may overwrite the artifacts' manual overrides. Ignored if `disableArtifactGeneration` is \"true\".", alias="forceUpdateExistingArtifacts")
    last_extraction_time_offset_weeks: Optional[StrictInt] = Field(default=None, description="The number of weeks from which to retrieve data. This overrides the last extraction date to retrieve more data.", alias="lastExtractionTimeOffsetWeeks")
    months_to_extract: Optional[StrictInt] = Field(default=None, description="The number of months to retrieve snapshot data from.", alias="monthsToExtract")
    override_last_extraction_timestamp: Optional[StrictStr] = Field(default=None, description="An epoch timestamp in milliseconds from which to retrieve data. This overrides the last extraction date to retrieve more data.", alias="overrideLastExtractionTimestamp")
    publish_data_load_artifacts: Optional[StrictBool] = Field(default=None, description="If \"true\", publishes the project to production.", alias="publishDataLoadArtifacts")
    run_processing_job: Optional[StrictBool] = Field(default=None, description="If \"true\", runs a processing job to generate a data version after the extraction job succeeds.", alias="runProcessingJob")
    spill_debug_info_detail_level_dto: Optional[StrictStr] = Field(default=None, description="The detail level of the debugging info to be generated", alias="spillDebugInfoDetailLevelDTO")
    spill_debug_info_partitions_dto: Optional[StrictStr] = Field(default=None, description="The partitioning of debugging info to be generated, if any", alias="spillDebugInfoPartitionsDTO")
    sql_batch_size: Optional[StrictInt] = Field(default=None, description="The maximum amount of SQL table records the job can retrieve in each batch.", alias="sqlBatchSize")
    tenants: Optional[List[StrictStr]] = Field(default=None, description="The unique IDs of the tenants to run an extraction job for.")
    __properties: ClassVar[List[str]] = ["allTenants", "batchSizeOverride", "connectorIds", "dataCategoryId", "disableArtifactGeneration", "excludedTenants", "extractToTimeOverride", "forceUpdateExistingArtifacts", "lastExtractionTimeOffsetWeeks", "monthsToExtract", "overrideLastExtractionTimestamp", "publishDataLoadArtifacts", "runProcessingJob", "spillDebugInfoDetailLevelDTO", "spillDebugInfoPartitionsDTO", "sqlBatchSize", "tenants"]

    @field_validator('spill_debug_info_detail_level_dto')
    def spill_debug_info_detail_level_dto_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['fileAndLine', 'mappingName']):
            raise ValueError("must be one of enum values ('fileAndLine', 'mappingName')")
        return value

    @field_validator('spill_debug_info_partitions_dto')
    def spill_debug_info_partitions_dto_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['spillNone', 'spillStagesAndRecords', 'spillAll']):
            raise ValueError("must be one of enum values ('spillNone', 'spillStagesAndRecords', 'spillAll')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ExtractDataAndLoadDTO from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ExtractDataAndLoadDTO from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "allTenants": obj.get("allTenants"),
            "batchSizeOverride": obj.get("batchSizeOverride"),
            "connectorIds": obj.get("connectorIds"),
            "dataCategoryId": obj.get("dataCategoryId"),
            "disableArtifactGeneration": obj.get("disableArtifactGeneration"),
            "excludedTenants": obj.get("excludedTenants"),
            "extractToTimeOverride": obj.get("extractToTimeOverride"),
            "forceUpdateExistingArtifacts": obj.get("forceUpdateExistingArtifacts"),
            "lastExtractionTimeOffsetWeeks": obj.get("lastExtractionTimeOffsetWeeks"),
            "monthsToExtract": obj.get("monthsToExtract"),
            "overrideLastExtractionTimestamp": obj.get("overrideLastExtractionTimestamp"),
            "publishDataLoadArtifacts": obj.get("publishDataLoadArtifacts"),
            "runProcessingJob": obj.get("runProcessingJob"),
            "spillDebugInfoDetailLevelDTO": obj.get("spillDebugInfoDetailLevelDTO"),
            "spillDebugInfoPartitionsDTO": obj.get("spillDebugInfoPartitionsDTO"),
            "sqlBatchSize": obj.get("sqlBatchSize"),
            "tenants": obj.get("tenants")
        })
        return _obj





# coding: utf-8

"""
    Visier Data In APIs

    Visier APIs for sending data to Visier and running data load jobs.

    The version of the OpenAPI document: 22222222.99201.1614
    Contact: alpine@visier.com

    Please note that this SDK is currently in beta.
    Functionality and behavior may change in future releases.
    We encourage you to provide feedback and report any issues encountered during your use.
"""  # noqa: E501


import unittest

import visier_api_data_in.models
from visier_api_data_in.models.data_provider_auth_information_dto import DataProviderAuthInformationDTO

class TestDataProviderAuthInformationDTO(unittest.TestCase):
    """DataProviderAuthInformationDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DataProviderAuthInformationDTO:
        """Test DataProviderAuthInformationDTO
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """

        if include_optional:
            return DataProviderAuthInformationDTO(
                data_provider_auth_params = visier_api_data_in.models.data_provider_auth_params_dto.DataProviderAuthParamsDTO(
                    adp_auth_params = visier_api_data_in.models.adp_auth_params_dto.AdpAuthParamsDTO(
                        auth_code = '', ), 
                    auth_context = 'DefaultDataExtraction', 
                    bamboo_auth_params = visier_api_data_in.models.bamboo_auth_params_dto.BambooAuthParamsDTO(
                        access_key = '', 
                        tenant_domain_name = '', ), 
                    big_query_auth_params = visier_api_data_in.models.big_query_auth_params_dto.BigQueryAuthParamsDTO(
                        client_id = '', 
                        client_secret = '', 
                        dataset_location = '', 
                        default_dataset = '', 
                        project_id = '', 
                        refresh_token = '', 
                        service_account_params = visier_api_data_in.models.big_query_service_account_params_dto.BigQueryServiceAccountParamsDTO(
                            private_key = '', 
                            service_account_email = '', ), ), 
                    copy_s3_auth_params = visier_api_data_in.models.copy_s3_auth_params_dto.CopyS3AuthParamsDTO(
                        iam_role = '', ), 
                    dayforce_v2_auth_params = visier_api_data_in.models.dayforce_v2_auth_params_dto.DayforceV2AuthParamsDTO(
                        company_id = '', 
                        host_domain_name = '', 
                        password = '', 
                        token_host = '', 
                        username = '', ), 
                    dimensions_auth_params = visier_api_data_in.models.dimensions_auth_params_dto.DimensionsAuthParamsDTO(
                        app_key = '', 
                        client_id = '', 
                        client_secret = '', 
                        password = '', 
                        username = '', 
                        vanity_url = '', ), 
                    empty_auth_params = {}, 
                    fusion_auth_params = visier_api_data_in.models.fusion_auth_params_dto.FusionAuthParamsDTO(
                        host_domain_name = '', 
                        password = '', 
                        username = '', ), 
                    gong_auth_params = visier_api_data_in.models.gong_auth_params_dto.GongAuthParamsDTO(
                        client_id = '', 
                        client_secret = '', ), 
                    google_sheets_auth_params = visier_api_data_in.models.google_sheets_auth_params_dto.GoogleSheetsAuthParamsDTO(
                        auth_code = '', 
                        client_id = '', 
                        client_secret = '', 
                        configuration = '', ), 
                    google_workspace_auth_params = visier_api_data_in.models.google_workspace_auth_params_dto.GoogleWorkspaceAuthParamsDTO(
                        auth_code = '', 
                        client_id = '', 
                        client_secret = '', 
                        privacy_mode = '', 
                        service_account = '', ), 
                    greenhouse_auth_params = visier_api_data_in.models.greenhouse_auth_params_dto.GreenhouseAuthParamsDTO(
                        api_key = '', ), 
                    has_updates = True, 
                    icims_auth_params = visier_api_data_in.models.icims_auth_params_dto.IcimsAuthParamsDTO(
                        client_id = '', 
                        client_secret = '', 
                        customer_id = '', 
                        password = '', 
                        region = 'US', 
                        username = '', ), 
                    internal_s3_auth_params = visier_api_data_in.models.internal_s3_auth_params_dto.InternalS3AuthParamsDTO(
                        bucket_name = '', 
                        path = '', ), 
                    jdbc_auth_params = visier_api_data_in.models.jdbc_auth_params_dto.JdbcAuthParamsDTO(
                        jdbc_connect_string = '', 
                        password = '', 
                        username = '', ), 
                    jira_auth_params = visier_api_data_in.models.jira_auth_params_dto.JiraAuthParamsDTO(
                        api_token = '', 
                        connect_params = visier_api_data_in.models.jira_connect_params_dto.JiraConnectParamsDTO(
                            app_key = '', 
                            client_key = '', 
                            shared_secret = '', ), 
                        host_name = '', ), 
                    lever_auth_params = visier_api_data_in.models.lever_auth_params_dto.LeverAuthParamsDTO(
                        api_key = '', ), 
                    medallia_auth_params = visier_api_data_in.models.medallia_auth_params_dto.MedalliaAuthParamsDTO(
                        client_id = '', 
                        client_secret = '', 
                        instance_url = '', 
                        tenant_domain_name = '', ), 
                    ms365_auth_params = visier_api_data_in.models.microsoft365_auth_params_dto.Microsoft365AuthParamsDTO(
                        client_id = '', 
                        client_secret = '', 
                        o_auth_tenant_id = '', 
                        privacy_mode = '', ), 
                    my_sql_auth_params = visier_api_data_in.models.my_sql_auth_params_dto.MySqlAuthParamsDTO(
                        database = '', 
                        host = '', 
                        password = '', 
                        port = '', 
                        ssl_mode = '', 
                        username = '', ), 
                    namely_auth_params = visier_api_data_in.models.namely_auth_params_dto.NamelyAuthParamsDTO(
                        auth_code = '', ), 
                    oracle_db_auth_params = visier_api_data_in.models.oracle_db_auth_params_dto.OracleDbAuthParamsDTO(
                        host = '', 
                        password = '', 
                        port = '', 
                        service_name = '', 
                        username = '', ), 
                    provider = 'Bamboo', 
                    qualtrics_auth_params = visier_api_data_in.models.qualtrics_auth_params_dto.QualtricsAuthParamsDTO(
                        api_token = '', 
                        data_center_id = '', ), 
                    redshift_auth_params = visier_api_data_in.models.redshift_auth_params_dto.RedshiftAuthParamsDTO(
                        database = '', 
                        endpoint = '', 
                        password = '', 
                        port = '', 
                        schema = '', 
                        table_prefix = '', 
                        username = '', ), 
                    s3_auth_params = visier_api_data_in.models.basic_s3_auth_params_dto.BasicS3AuthParamsDTO(
                        access_key = '', 
                        bucket_name = '', 
                        bucket_region = '', 
                        path = '', 
                        secret_key = '', ), 
                    salesforce_auth_params = visier_api_data_in.models.salesforce_auth_params_dto.SalesforceAuthParamsDTO(
                        client_id = '', 
                        refresh_token = '', ), 
                    salesforce_v2_auth_params = visier_api_data_in.models.salesforce_v2_auth_params_dto.SalesforceV2AuthParamsDTO(
                        auth_code = '', 
                        client_id = '', 
                        client_secret = '', 
                        login_host = '', ), 
                    service_now_auth_params = visier_api_data_in.models.service_now_auth_params_dto.ServiceNowAuthParamsDTO(
                        host_domain_name = '', 
                        password = '', 
                        username = '', ), 
                    service_now_v2_auth_params = visier_api_data_in.models.service_now_v2_auth_params_dto.ServiceNowV2AuthParamsDTO(
                        alternate_domain = '', 
                        auth_code = '', 
                        client_id = '', 
                        client_secret = '', 
                        host_domain_name = '', ), 
                    slack_auth_params = visier_api_data_in.models.slack_auth_params_dto.SlackAuthParamsDTO(
                        auth_code = '', 
                        client_id = '', 
                        client_secret = '', ), 
                    snowflake_auth_params = visier_api_data_in.models.snowflake_auth_params_dto.SnowflakeAuthParamsDTO(
                        account_identifier = '', 
                        database = '', 
                        password = '', 
                        private_key = '', 
                        schema = '', 
                        username = '', 
                        warehouse = '', ), 
                    sql_server_auth_params = visier_api_data_in.models.sql_server_auth_params_dto.SqlServerAuthParamsDTO(
                        database = '', 
                        host = '', 
                        password = '', 
                        port = '', 
                        username = '', ), 
                    success_factors_auth_params = visier_api_data_in.models.success_factors_auth_params_dto.SuccessFactorsAuthParamsDTO(
                        company_id = '', 
                        host_domain_name = '', 
                        o_auth = visier_api_data_in.models.success_factors_o_auth_params_dto.SuccessFactorsOAuthParamsDTO(
                            api_key = '', 
                            private_x509_key = '', 
                            public_x509_cert = '', ), 
                        password = '', 
                        username = '', ), 
                    tenant_domain_name = '', 
                    ultimate_auth_params = visier_api_data_in.models.ultimate_auth_params_dto.UltimateAuthParamsDTO(
                        api_key = '', 
                        host_domain_name = '', 
                        password = '', 
                        user_access_key = '', 
                        username = '', ), 
                    willow_auth_params = visier_api_data_in.models.willow_auth_params_dto.WillowAuthParamsDTO(
                        api_token = '', 
                        host_name = '', ), 
                    workday_auth_params = visier_api_data_in.models.workday_auth_params_dto.WorkdayAuthParamsDTO(
                        api_key = '', 
                        domain_name = '', 
                        implementation_name = '', 
                        integration_system_id = '', 
                        password = '', 
                        ref_token = visier_api_data_in.models.workday_refresh_token_params_dto.WorkdayRefreshTokenParamsDTO(
                            api_client_id = '', 
                            client_secret = '', 
                            refresh_token = '', ), 
                        user_id = '', ), 
                    workday_raas_auth_params = visier_api_data_in.models.workday_raas_auth_params_dto.WorkdayRaasAuthParamsDTO(
                        domain_name = '', 
                        implementation_name = '', 
                        password = '', 
                        test_report_url = '', 
                        user_id = '', ), 
                    zoom_auth_params = visier_api_data_in.models.zoom_auth_params_dto.ZoomAuthParamsDTO(
                        auth_code = '', 
                        client_id = '', 
                        client_secret = '', ), ),
                data_provider_basic_information = visier_api_data_in.models.data_provider_basic_information_dto.DataProviderBasicInformationDTO(
                    description = '', 
                    display_name = '', ),
                data_provider_metadata = visier_api_data_in.models.data_provider_basic_metadata_dto.DataProviderBasicMetadataDTO(
                    can_children_inherit = True, )
            )
        else:
            return DataProviderAuthInformationDTO(
        )

    def testDataProviderAuthInformationDTO(self):
        """Test DataProviderAuthInformationDTO"""
        def validate_instance(instance):
            DataProviderAuthInformationDTO.model_validate(inst_req_only)
            instance_deserialized = DataProviderAuthInformationDTO.from_dict(instance.to_dict())
            assert instance == instance_deserialized

        inst_req_only = self.make_instance(include_optional=False)
        validate_instance(inst_req_only)

        inst_req_and_optional = self.make_instance(include_optional=True)
        validate_instance(inst_req_and_optional)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Visier Data In APIs

    Visier APIs for sending data to Visier and running data load jobs.

    The version of the OpenAPI document: 22222222.99201.1614
    Contact: alpine@visier.com

    Please note that this SDK is currently in beta.
    Functionality and behavior may change in future releases.
    We encourage you to provide feedback and report any issues encountered during your use.
"""  # noqa: E501


import unittest

from visier_api_data_in.api.data_and_job_handling_api import DataAndJobHandlingApi


class TestDataAndJobHandlingApi(unittest.TestCase):
    """DataAndJobHandlingApi unit test stubs"""

    def setUp(self) -> None:
        self.api = DataAndJobHandlingApi()

    def tearDown(self) -> None:
        pass

    def test_adhoc_consolidated_analytics_job(self) -> None:
        """Test case for adhoc_consolidated_analytics_job

        Run a consolidated analytics job
        """
        pass

    def test_adhoc_extraction_job(self) -> None:
        """Test case for adhoc_extraction_job

        Run a data connector extraction job
        """
        pass

    def test_adhoc_processing_jobs(self) -> None:
        """Test case for adhoc_processing_jobs

        Run a processing job
        """
        pass

    def test_assign_connector_credential(self) -> None:
        """Test case for assign_connector_credential

        Assign connector credentials to data connectors
        """
        pass

    def test_cancel_jobs(self) -> None:
        """Test case for cancel_jobs

        Cancel a list of jobs
        """
        pass

    def test_create_connector_credential(self) -> None:
        """Test case for create_connector_credential

        Create a connector credential
        """
        pass

    def test_data_connector_credentials(self) -> None:
        """Test case for data_connector_credentials

        Retrieve a list of all data connector credentials
        """
        pass

    def test_data_connectors(self) -> None:
        """Test case for data_connectors

        Retrieve a list of all data connectors
        """
        pass

    def test_delete_connector_credential(self) -> None:
        """Test case for delete_connector_credential

        Delete a connector credential
        """
        pass

    def test_disable_dv(self) -> None:
        """Test case for disable_dv

        Disable data versions for a list of analytic tenants
        """
        pass

    def test_dispatching_job_status(self) -> None:
        """Test case for dispatching_job_status

        Retrieve a dispatching job's status
        """
        pass

    def test_exclude_data_uplaods(self) -> None:
        """Test case for exclude_data_uplaods

        Exclude data uploads
        """
        pass

    def test_extraction_job_and_status(self) -> None:
        """Test case for extraction_job_and_status

        Retrieve a dispatching job's extraction jobs with their statuses
        """
        pass

    def test_include_data_uploads(self) -> None:
        """Test case for include_data_uploads

        Include data uploads
        """
        pass

    def test_job_id_status(self) -> None:
        """Test case for job_id_status

        Retrieve a specific job's status
        """
        pass

    def test_job_status(self) -> None:
        """Test case for job_status

        Retrieve the statuses of all jobs
        """
        pass

    def test_latest_enabled_dv(self) -> None:
        """Test case for latest_enabled_dv

        Retrieve the latest enabled data versions for all analytic tenants
        """
        pass

    def test_list_connector_settings(self) -> None:
        """Test case for list_connector_settings

        Retrieve data connector settings
        """
        pass

    def test_processing_job_and_status(self) -> None:
        """Test case for processing_job_and_status

        Retrieve a dispatching job's processing jobs with their statuses
        """
        pass

    def test_processing_job_status(self) -> None:
        """Test case for processing_job_status

        Retrieve processing job statuses by receiving job ID
        """
        pass

    def test_receiving_job_and_status(self) -> None:
        """Test case for receiving_job_and_status

        Retrieve a dispatching job's receiving jobs with their statuses
        """
        pass

    def test_receiving_job_status(self) -> None:
        """Test case for receiving_job_status

        Retrieve a receiving job's status
        """
        pass

    def test_retrieve_data_categories(self) -> None:
        """Test case for retrieve_data_categories

        Retrieve a list of all data categories
        """
        pass

    def test_retrieve_data_uploads(self) -> None:
        """Test case for retrieve_data_uploads

        Retrieve data uploads
        """
        pass

    def test_set_connector_setting(self) -> None:
        """Test case for set_connector_setting

        Update data connector settings
        """
        pass

    def test_start_extraction(self) -> None:
        """Test case for start_extraction

        Trigger data connector extraction jobs
        """
        pass

    def test_start_load(self) -> None:
        """Test case for start_load

        Start the data load for analytic tenants
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Visier Data In APIs

    Visier APIs for sending data to Visier and running data load jobs.

    The version of the OpenAPI document: 22222222.99201.1614
    Contact: alpine@visier.com

    Please note that this SDK is currently in beta.
    Functionality and behavior may change in future releases.
    We encourage you to provide feedback and report any issues encountered during your use.
"""  # noqa: E501


import unittest

from visier_api_data_in.api.data_intake_api import DataIntakeApi


class TestDataIntakeApi(unittest.TestCase):
    """DataIntakeApi unit test stubs"""

    def setUp(self) -> None:
        self.api = DataIntakeApi()

    def tearDown(self) -> None:
        pass

    def test_get_sources(self) -> None:
        """Test case for get_sources

        Retrieve a list of sources
        """
        pass

    def test_push_data(self) -> None:
        """Test case for push_data

        Transfer data to sources via JSON
        """
        pass

    def test_push_data_cancel(self) -> None:
        """Test case for push_data_cancel

        Cancel a transfer session
        """
        pass

    def test_push_data_complete(self) -> None:
        """Test case for push_data_complete

        Complete a transfer session
        """
        pass

    def test_start_transfer(self) -> None:
        """Test case for start_transfer

        Start a transfer session
        """
        pass

    def test_upload_data(self) -> None:
        """Test case for upload_data

        Transfer data to sources via file upload
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    Visier Data In APIs

    Visier APIs for sending data to Visier and running data load jobs.

    The version of the OpenAPI document: 22222222.99201.1614
    Contact: alpine@visier.com

    Please note that this SDK is currently in beta.
    Functionality and behavior may change in future releases.
    We encourage you to provide feedback and report any issues encountered during your use.
"""  # noqa: E501


# import models into model package
from visier_api_data_in.models.adp_auth_params_dto import AdpAuthParamsDTO
from visier_api_data_in.models.assign_connector_credential_request import AssignConnectorCredentialRequest
from visier_api_data_in.models.assign_connector_credentials_by_tenant_response_dto import AssignConnectorCredentialsByTenantResponseDTO
from visier_api_data_in.models.assign_connector_credentials_response_dto import AssignConnectorCredentialsResponseDTO
from visier_api_data_in.models.assign_connector_with_credentials_response_dto import AssignConnectorWithCredentialsResponseDTO
from visier_api_data_in.models.assigned_credential_info_response_dto import AssignedCredentialInfoResponseDTO
from visier_api_data_in.models.bamboo_auth_params_dto import BambooAuthParamsDTO
from visier_api_data_in.models.basic_s3_auth_params_dto import BasicS3AuthParamsDTO
from visier_api_data_in.models.big_query_auth_params_dto import BigQueryAuthParamsDTO
from visier_api_data_in.models.big_query_service_account_params_dto import BigQueryServiceAccountParamsDTO
from visier_api_data_in.models.cancel_job_batch_from_job_id_dto import CancelJobBatchFromJobIdDTO
from visier_api_data_in.models.connector import Connector
from visier_api_data_in.models.connector_info_response_dto import ConnectorInfoResponseDTO
from visier_api_data_in.models.connector_setting_request_dto import ConnectorSettingRequestDTO
from visier_api_data_in.models.connector_setting_response_dto import ConnectorSettingResponseDTO
from visier_api_data_in.models.connector_settings_response_dto import ConnectorSettingsResponseDTO
from visier_api_data_in.models.consolidated_analytics_job_request_dto import ConsolidatedAnalyticsJobRequestDTO
from visier_api_data_in.models.copy_s3_auth_params_dto import CopyS3AuthParamsDTO
from visier_api_data_in.models.credential_creation_api_response_dto import CredentialCreationAPIResponseDTO
from visier_api_data_in.models.data_categories_response_dto import DataCategoriesResponseDTO
from visier_api_data_in.models.data_category_response_dto import DataCategoryResponseDTO
from visier_api_data_in.models.data_load_request import DataLoadRequest
from visier_api_data_in.models.data_load_request_model import DataLoadRequestModel
from visier_api_data_in.models.data_load_response import DataLoadResponse
from visier_api_data_in.models.data_provider_auth_information_dto import DataProviderAuthInformationDTO
from visier_api_data_in.models.data_provider_auth_params_dto import DataProviderAuthParamsDTO
from visier_api_data_in.models.data_provider_basic_information_dto import DataProviderBasicInformationDTO
from visier_api_data_in.models.data_provider_basic_metadata_dto import DataProviderBasicMetadataDTO
from visier_api_data_in.models.data_transfer_result_detail import DataTransferResultDetail
from visier_api_data_in.models.data_version_and_date_dto import DataVersionAndDateDTO
from visier_api_data_in.models.data_version_object import DataVersionObject
from visier_api_data_in.models.dayforce_v2_auth_params_dto import DayforceV2AuthParamsDTO
from visier_api_data_in.models.dimensions_auth_params_dto import DimensionsAuthParamsDTO
from visier_api_data_in.models.direct_data_job_config_dto import DirectDataJobConfigDTO
from visier_api_data_in.models.direct_data_job_status_response_dto import DirectDataJobStatusResponseDTO
from visier_api_data_in.models.direct_data_load_config_dto import DirectDataLoadConfigDTO
from visier_api_data_in.models.direct_data_schema_dto import DirectDataSchemaDTO
from visier_api_data_in.models.direct_data_schema_field_dto import DirectDataSchemaFieldDTO
from visier_api_data_in.models.direct_data_transaction_start_response_dto import DirectDataTransactionStartResponseDTO
from visier_api_data_in.models.direct_data_upload_file_response_dto import DirectDataUploadFileResponseDTO
from visier_api_data_in.models.disable_dv_model import DisableDVModel
from visier_api_data_in.models.disable_dv_request import DisableDVRequest
from visier_api_data_in.models.disable_dv_response import DisableDVResponse
from visier_api_data_in.models.dispatching_job_status_response import DispatchingJobStatusResponse
from visier_api_data_in.models.exclude_data_uploads_request import ExcludeDataUploadsRequest
from visier_api_data_in.models.extract_data_and_load_dto import ExtractDataAndLoadDTO
from visier_api_data_in.models.extraction_job import ExtractionJob
from visier_api_data_in.models.extraction_job_and_status_response import ExtractionJobAndStatusResponse
from visier_api_data_in.models.extractor_credential_apidto import ExtractorCredentialAPIDTO
from visier_api_data_in.models.extractor_credentials_apidto import ExtractorCredentialsAPIDTO
from visier_api_data_in.models.extractor_setting_apidto import ExtractorSettingAPIDTO
from visier_api_data_in.models.extractor_setting_key_value_apidto import ExtractorSettingKeyValueAPIDTO
from visier_api_data_in.models.extractor_settings_apidto import ExtractorSettingsAPIDTO
from visier_api_data_in.models.fusion_auth_params_dto import FusionAuthParamsDTO
from visier_api_data_in.models.gong_auth_params_dto import GongAuthParamsDTO
from visier_api_data_in.models.google_protobuf_any import GoogleProtobufAny
from visier_api_data_in.models.google_sheets_auth_params_dto import GoogleSheetsAuthParamsDTO
from visier_api_data_in.models.google_workspace_auth_params_dto import GoogleWorkspaceAuthParamsDTO
from visier_api_data_in.models.greenhouse_auth_params_dto import GreenhouseAuthParamsDTO
from visier_api_data_in.models.icims_auth_params_dto import IcimsAuthParamsDTO
from visier_api_data_in.models.import_definition_apidto import ImportDefinitionAPIDTO
from visier_api_data_in.models.import_definitions_apidto import ImportDefinitionsAPIDTO
from visier_api_data_in.models.include_data_uploads_request import IncludeDataUploadsRequest
from visier_api_data_in.models.internal_s3_auth_params_dto import InternalS3AuthParamsDTO
from visier_api_data_in.models.jdbc_auth_params_dto import JdbcAuthParamsDTO
from visier_api_data_in.models.jira_auth_params_dto import JiraAuthParamsDTO
from visier_api_data_in.models.jira_connect_params_dto import JiraConnectParamsDTO
from visier_api_data_in.models.job_cancellation_result_dto import JobCancellationResultDTO
from visier_api_data_in.models.job_cancellation_results_dto import JobCancellationResultsDTO
from visier_api_data_in.models.job_id_response import JobIdResponse
from visier_api_data_in.models.job_status_list_response import JobStatusListResponse
from visier_api_data_in.models.job_status_with_start_time import JobStatusWithStartTime
from visier_api_data_in.models.key_pair_delete_response_dto import KeyPairDeleteResponseDTO
from visier_api_data_in.models.key_pair_generate_request_dto import KeyPairGenerateRequestDTO
from visier_api_data_in.models.lever_auth_params_dto import LeverAuthParamsDTO
from visier_api_data_in.models.medallia_auth_params_dto import MedalliaAuthParamsDTO
from visier_api_data_in.models.microsoft365_auth_params_dto import Microsoft365AuthParamsDTO
from visier_api_data_in.models.multiple_tenant_data_versions_details_dto import MultipleTenantDataVersionsDetailsDTO
from visier_api_data_in.models.multiple_tenant_data_versions_list_dto import MultipleTenantDataVersionsListDTO
from visier_api_data_in.models.my_sql_auth_params_dto import MySqlAuthParamsDTO
from visier_api_data_in.models.namely_auth_params_dto import NamelyAuthParamsDTO
from visier_api_data_in.models.oracle_db_auth_params_dto import OracleDbAuthParamsDTO
from visier_api_data_in.models.plan_data_load_change_dto import PlanDataLoadChangeDTO
from visier_api_data_in.models.plan_data_load_change_list_dto import PlanDataLoadChangeListDTO
from visier_api_data_in.models.plan_data_load_error_dto import PlanDataLoadErrorDTO
from visier_api_data_in.models.plan_data_upload_response_dto import PlanDataUploadResponseDTO
from visier_api_data_in.models.plan_row_data_load_response_dto import PlanRowDataLoadResponseDTO
from visier_api_data_in.models.processing_job import ProcessingJob
from visier_api_data_in.models.processing_job_and_status_response import ProcessingJobAndStatusResponse
from visier_api_data_in.models.processing_job_request_dto import ProcessingJobRequestDTO
from visier_api_data_in.models.processing_job_status_response import ProcessingJobStatusResponse
from visier_api_data_in.models.public_key_dto import PublicKeyDTO
from visier_api_data_in.models.public_keys_dto import PublicKeysDTO
from visier_api_data_in.models.push_data_cancel_response import PushDataCancelResponse
from visier_api_data_in.models.push_data_column_definition_dto import PushDataColumnDefinitionDTO
from visier_api_data_in.models.push_data_complete_request import PushDataCompleteRequest
from visier_api_data_in.models.push_data_complete_response import PushDataCompleteResponse
from visier_api_data_in.models.push_data_response import PushDataResponse
from visier_api_data_in.models.push_data_source_definition_dto import PushDataSourceDefinitionDTO
from visier_api_data_in.models.push_data_source_definitions_dto import PushDataSourceDefinitionsDTO
from visier_api_data_in.models.qualtrics_auth_params_dto import QualtricsAuthParamsDTO
from visier_api_data_in.models.receiving_job import ReceivingJob
from visier_api_data_in.models.receiving_job_and_status_response import ReceivingJobAndStatusResponse
from visier_api_data_in.models.receiving_job_status_response import ReceivingJobStatusResponse
from visier_api_data_in.models.redshift_auth_params_dto import RedshiftAuthParamsDTO
from visier_api_data_in.models.result import Result
from visier_api_data_in.models.salesforce_auth_params_dto import SalesforceAuthParamsDTO
from visier_api_data_in.models.salesforce_v2_auth_params_dto import SalesforceV2AuthParamsDTO
from visier_api_data_in.models.service_now_auth_params_dto import ServiceNowAuthParamsDTO
from visier_api_data_in.models.service_now_v2_auth_params_dto import ServiceNowV2AuthParamsDTO
from visier_api_data_in.models.set_connector_setting_request_dto import SetConnectorSettingRequestDTO
from visier_api_data_in.models.set_connector_setting_response_dto import SetConnectorSettingResponseDTO
from visier_api_data_in.models.set_connector_settings_request_dto import SetConnectorSettingsRequestDTO
from visier_api_data_in.models.set_connector_settings_response_dto import SetConnectorSettingsResponseDTO
from visier_api_data_in.models.slack_auth_params_dto import SlackAuthParamsDTO
from visier_api_data_in.models.snowflake_auth_params_dto import SnowflakeAuthParamsDTO
from visier_api_data_in.models.source import Source
from visier_api_data_in.models.sql_server_auth_params_dto import SqlServerAuthParamsDTO
from visier_api_data_in.models.start_extraction_model import StartExtractionModel
from visier_api_data_in.models.start_extraction_request import StartExtractionRequest
from visier_api_data_in.models.start_extraction_response import StartExtractionResponse
from visier_api_data_in.models.start_transfer_response import StartTransferResponse
from visier_api_data_in.models.status import Status
from visier_api_data_in.models.subject_missing_access_dto import SubjectMissingAccessDTO
from visier_api_data_in.models.success_factors_auth_params_dto import SuccessFactorsAuthParamsDTO
from visier_api_data_in.models.success_factors_o_auth_params_dto import SuccessFactorsOAuthParamsDTO
from visier_api_data_in.models.tenant import Tenant
from visier_api_data_in.models.tenant_and_credential import TenantAndCredential
from visier_api_data_in.models.tenant_connector_settings_request_dto import TenantConnectorSettingsRequestDTO
from visier_api_data_in.models.tenant_data_upload_status_response_dto import TenantDataUploadStatusResponseDTO
from visier_api_data_in.models.tenant_data_upload_update_status_response_dto import TenantDataUploadUpdateStatusResponseDTO
from visier_api_data_in.models.tenant_data_uploads_list_response_dto import TenantDataUploadsListResponseDTO
from visier_api_data_in.models.tenant_data_uploads_response_dto import TenantDataUploadsResponseDTO
from visier_api_data_in.models.tenant_data_uploads_update_response_dto import TenantDataUploadsUpdateResponseDTO
from visier_api_data_in.models.ultimate_auth_params_dto import UltimateAuthParamsDTO
from visier_api_data_in.models.upload_to_exclude import UploadToExclude
from visier_api_data_in.models.upload_to_exclude_model import UploadToExcludeModel
from visier_api_data_in.models.upload_to_include import UploadToInclude
from visier_api_data_in.models.upload_to_include_model import UploadToIncludeModel
from visier_api_data_in.models.willow_auth_params_dto import WillowAuthParamsDTO
from visier_api_data_in.models.workday_auth_params_dto import WorkdayAuthParamsDTO
from visier_api_data_in.models.workday_o_auth_params_dto import WorkdayOAuthParamsDTO
from visier_api_data_in.models.workday_raas_auth_params_dto import WorkdayRaasAuthParamsDTO
from visier_api_data_in.models.workday_refresh_token_params_dto import WorkdayRefreshTokenParamsDTO
from visier_api_data_in.models.zoom_auth_params_dto import ZoomAuthParamsDTO



# coding: utf-8

"""
    Visier Data In APIs

    Visier APIs for sending data to Visier and running data load jobs.

    The version of the OpenAPI document: 22222222.99201.1614
    Contact: alpine@visier.com

    Please note that this SDK is currently in beta.
    Functionality and behavior may change in future releases.
    We encourage you to provide feedback and report any issues encountered during your use.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from visier_api_core import ApiClient, ApiResponse, RequestSerialized, RESTResponseType

from pydantic import Field, StrictBytes, StrictStr
from typing import Optional, Tuple, Union
from typing_extensions import Annotated
from visier_api_data_in.models.plan_data_upload_response_dto import PlanDataUploadResponseDTO
from visier_api_data_in.models.plan_row_data_load_response_dto import PlanRowDataLoadResponseDTO
import visier_api_data_in.models


class PlanningDataLoadApi:
    """
    This class provides methods to make requests to the Visier API.
    It uses the ApiClient to handle the HTTP requests and responses.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def plan_data_load_plan_data_upload(
        self,
        plan_id: Annotated[StrictStr, Field(description="The unique identifier of the plan.")],
        scenario_id: Annotated[StrictStr, Field(description="The unique identifier of the plan scenario to load data into.")],
        calculation: Annotated[Optional[StrictStr], Field(description="Sets the plan values to rollup, distribute, or neither. Valid values:   - **ROLLUP**: Roll up children data values to parent data values. If the data provides a parent value and its child value, this method prioritizes the loaded value for the child and and overwrites the parent.   - **DISTRIBUTE**: Distribute parent data values to their children. If the value of the child conflicts with the calculated distribution, this method overrides the loaded child value.   - **NONE**: The loaded values are neither rolled up or distributed. This is the default.")] = None,
        currency: Annotated[Optional[StrictStr], Field(description="The 3-digit ISO 4217 currency code of the data. If undefined, default is the plan's consolidation currency. If the currency is different from the plan's consolidation currency, the values are converted to the consolidation currency using the conversion rates loaded for the plan's baseline period.")] = None,
        method: Annotated[Optional[StrictStr], Field(description="Sets how to validate the data being loaded into Visier. Valid values:   - **VALIDATE**: Runs a test load through all the validation steps without putting the data into the plan. Use `VALIDATE` to find any errors before using `STRICT_UPLOAD` to load the data.   - **SKIP_ERRORS**: Loads all data without errors into the plan. Any rows with errors are excluded from the plan.   - **STRICT_UPLOAD**: Loads data into the plan if there are no errors in any row. If there are errors, the load fails. This is the default.")] = None,
        target_tenant_id: Annotated[Optional[StrictStr], Field(description="Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.")] = None,
        file: Annotated[Optional[Union[StrictBytes, StrictStr, Tuple[StrictStr, StrictBytes]]], Field(description="The CSV file to load into the plan.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> PlanDataUploadResponseDTO:
        """Upload plan data

        Send a file to Visier to modify a plan's data. The file must be in CSV format and match the plan's schema. To get the plan's schema, call `GET /v1alpha/planning/model/plans/{id}?withSchema=true`. The data file must contain the following columns:   - `periodId`: From the GET response, use the `date` values in the `timePeriods` array as values in this column.   - A column for each `id` value in the `planSegmentLevels` object, where the row value is the `id` of the `members` in the `planSegmentLevelMembers` object.   - A column for each  `id` value in the `planItems` object that you want to modify data for, where the row value is the data value.  <br>**Note:** <em>This API is in **alpha**. While in alpha, APIs may change in a breaking way without notice; functionality may be removed, and no deprecation notices will be issued. If you are interested in using this API, please contact your Customer Success Manager (CSM).</em>

        :param plan_id: The unique identifier of the plan. (required)
        :type plan_id: str
        :param scenario_id: The unique identifier of the plan scenario to load data into. (required)
        :type scenario_id: str
        :param calculation: Sets the plan values to rollup, distribute, or neither. Valid values:   - **ROLLUP**: Roll up children data values to parent data values. If the data provides a parent value and its child value, this method prioritizes the loaded value for the child and and overwrites the parent.   - **DISTRIBUTE**: Distribute parent data values to their children. If the value of the child conflicts with the calculated distribution, this method overrides the loaded child value.   - **NONE**: The loaded values are neither rolled up or distributed. This is the default.
        :type calculation: str
        :param currency: The 3-digit ISO 4217 currency code of the data. If undefined, default is the plan's consolidation currency. If the currency is different from the plan's consolidation currency, the values are converted to the consolidation currency using the conversion rates loaded for the plan's baseline period.
        :type currency: str
        :param method: Sets how to validate the data being loaded into Visier. Valid values:   - **VALIDATE**: Runs a test load through all the validation steps without putting the data into the plan. Use `VALIDATE` to find any errors before using `STRICT_UPLOAD` to load the data.   - **SKIP_ERRORS**: Loads all data without errors into the plan. Any rows with errors are excluded from the plan.   - **STRICT_UPLOAD**: Loads data into the plan if there are no errors in any row. If there are errors, the load fails. This is the default.
        :type method: str
        :param target_tenant_id: Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.
        :type target_tenant_id: str
        :param file: The CSV file to load into the plan.
        :type file: bytearray
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._plan_data_load_plan_data_upload_serialize(
            plan_id=plan_id,
            scenario_id=scenario_id,
            calculation=calculation,
            currency=currency,
            method=method,
            target_tenant_id=target_tenant_id,
            file=file,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PlanDataUploadResponseDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            model_package=visier_api_data_in.models,
            response_data=response_data,
            response_types_map=_response_types_map
        ).data


    @validate_call
    def plan_data_load_plan_data_upload_with_http_info(
        self,
        plan_id: Annotated[StrictStr, Field(description="The unique identifier of the plan.")],
        scenario_id: Annotated[StrictStr, Field(description="The unique identifier of the plan scenario to load data into.")],
        calculation: Annotated[Optional[StrictStr], Field(description="Sets the plan values to rollup, distribute, or neither. Valid values:   - **ROLLUP**: Roll up children data values to parent data values. If the data provides a parent value and its child value, this method prioritizes the loaded value for the child and and overwrites the parent.   - **DISTRIBUTE**: Distribute parent data values to their children. If the value of the child conflicts with the calculated distribution, this method overrides the loaded child value.   - **NONE**: The loaded values are neither rolled up or distributed. This is the default.")] = None,
        currency: Annotated[Optional[StrictStr], Field(description="The 3-digit ISO 4217 currency code of the data. If undefined, default is the plan's consolidation currency. If the currency is different from the plan's consolidation currency, the values are converted to the consolidation currency using the conversion rates loaded for the plan's baseline period.")] = None,
        method: Annotated[Optional[StrictStr], Field(description="Sets how to validate the data being loaded into Visier. Valid values:   - **VALIDATE**: Runs a test load through all the validation steps without putting the data into the plan. Use `VALIDATE` to find any errors before using `STRICT_UPLOAD` to load the data.   - **SKIP_ERRORS**: Loads all data without errors into the plan. Any rows with errors are excluded from the plan.   - **STRICT_UPLOAD**: Loads data into the plan if there are no errors in any row. If there are errors, the load fails. This is the default.")] = None,
        target_tenant_id: Annotated[Optional[StrictStr], Field(description="Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.")] = None,
        file: Annotated[Optional[Union[StrictBytes, StrictStr, Tuple[StrictStr, StrictBytes]]], Field(description="The CSV file to load into the plan.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[PlanDataUploadResponseDTO]:
        """Upload plan data

        Send a file to Visier to modify a plan's data. The file must be in CSV format and match the plan's schema. To get the plan's schema, call `GET /v1alpha/planning/model/plans/{id}?withSchema=true`. The data file must contain the following columns:   - `periodId`: From the GET response, use the `date` values in the `timePeriods` array as values in this column.   - A column for each `id` value in the `planSegmentLevels` object, where the row value is the `id` of the `members` in the `planSegmentLevelMembers` object.   - A column for each  `id` value in the `planItems` object that you want to modify data for, where the row value is the data value.  <br>**Note:** <em>This API is in **alpha**. While in alpha, APIs may change in a breaking way without notice; functionality may be removed, and no deprecation notices will be issued. If you are interested in using this API, please contact your Customer Success Manager (CSM).</em>

        :param plan_id: The unique identifier of the plan. (required)
        :type plan_id: str
        :param scenario_id: The unique identifier of the plan scenario to load data into. (required)
        :type scenario_id: str
        :param calculation: Sets the plan values to rollup, distribute, or neither. Valid values:   - **ROLLUP**: Roll up children data values to parent data values. If the data provides a parent value and its child value, this method prioritizes the loaded value for the child and and overwrites the parent.   - **DISTRIBUTE**: Distribute parent data values to their children. If the value of the child conflicts with the calculated distribution, this method overrides the loaded child value.   - **NONE**: The loaded values are neither rolled up or distributed. This is the default.
        :type calculation: str
        :param currency: The 3-digit ISO 4217 currency code of the data. If undefined, default is the plan's consolidation currency. If the currency is different from the plan's consolidation currency, the values are converted to the consolidation currency using the conversion rates loaded for the plan's baseline period.
        :type currency: str
        :param method: Sets how to validate the data being loaded into Visier. Valid values:   - **VALIDATE**: Runs a test load through all the validation steps without putting the data into the plan. Use `VALIDATE` to find any errors before using `STRICT_UPLOAD` to load the data.   - **SKIP_ERRORS**: Loads all data without errors into the plan. Any rows with errors are excluded from the plan.   - **STRICT_UPLOAD**: Loads data into the plan if there are no errors in any row. If there are errors, the load fails. This is the default.
        :type method: str
        :param target_tenant_id: Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.
        :type target_tenant_id: str
        :param file: The CSV file to load into the plan.
        :type file: bytearray
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._plan_data_load_plan_data_upload_serialize(
            plan_id=plan_id,
            scenario_id=scenario_id,
            calculation=calculation,
            currency=currency,
            method=method,
            target_tenant_id=target_tenant_id,
            file=file,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PlanDataUploadResponseDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            model_package=visier_api_data_in.models,
            response_data=response_data,
            response_types_map=_response_types_map
        )


    @validate_call
    def plan_data_load_plan_data_upload_without_preload_content(
        self,
        plan_id: Annotated[StrictStr, Field(description="The unique identifier of the plan.")],
        scenario_id: Annotated[StrictStr, Field(description="The unique identifier of the plan scenario to load data into.")],
        calculation: Annotated[Optional[StrictStr], Field(description="Sets the plan values to rollup, distribute, or neither. Valid values:   - **ROLLUP**: Roll up children data values to parent data values. If the data provides a parent value and its child value, this method prioritizes the loaded value for the child and and overwrites the parent.   - **DISTRIBUTE**: Distribute parent data values to their children. If the value of the child conflicts with the calculated distribution, this method overrides the loaded child value.   - **NONE**: The loaded values are neither rolled up or distributed. This is the default.")] = None,
        currency: Annotated[Optional[StrictStr], Field(description="The 3-digit ISO 4217 currency code of the data. If undefined, default is the plan's consolidation currency. If the currency is different from the plan's consolidation currency, the values are converted to the consolidation currency using the conversion rates loaded for the plan's baseline period.")] = None,
        method: Annotated[Optional[StrictStr], Field(description="Sets how to validate the data being loaded into Visier. Valid values:   - **VALIDATE**: Runs a test load through all the validation steps without putting the data into the plan. Use `VALIDATE` to find any errors before using `STRICT_UPLOAD` to load the data.   - **SKIP_ERRORS**: Loads all data without errors into the plan. Any rows with errors are excluded from the plan.   - **STRICT_UPLOAD**: Loads data into the plan if there are no errors in any row. If there are errors, the load fails. This is the default.")] = None,
        target_tenant_id: Annotated[Optional[StrictStr], Field(description="Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.")] = None,
        file: Annotated[Optional[Union[StrictBytes, StrictStr, Tuple[StrictStr, StrictBytes]]], Field(description="The CSV file to load into the plan.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Upload plan data

        Send a file to Visier to modify a plan's data. The file must be in CSV format and match the plan's schema. To get the plan's schema, call `GET /v1alpha/planning/model/plans/{id}?withSchema=true`. The data file must contain the following columns:   - `periodId`: From the GET response, use the `date` values in the `timePeriods` array as values in this column.   - A column for each `id` value in the `planSegmentLevels` object, where the row value is the `id` of the `members` in the `planSegmentLevelMembers` object.   - A column for each  `id` value in the `planItems` object that you want to modify data for, where the row value is the data value.  <br>**Note:** <em>This API is in **alpha**. While in alpha, APIs may change in a breaking way without notice; functionality may be removed, and no deprecation notices will be issued. If you are interested in using this API, please contact your Customer Success Manager (CSM).</em>

        :param plan_id: The unique identifier of the plan. (required)
        :type plan_id: str
        :param scenario_id: The unique identifier of the plan scenario to load data into. (required)
        :type scenario_id: str
        :param calculation: Sets the plan values to rollup, distribute, or neither. Valid values:   - **ROLLUP**: Roll up children data values to parent data values. If the data provides a parent value and its child value, this method prioritizes the loaded value for the child and and overwrites the parent.   - **DISTRIBUTE**: Distribute parent data values to their children. If the value of the child conflicts with the calculated distribution, this method overrides the loaded child value.   - **NONE**: The loaded values are neither rolled up or distributed. This is the default.
        :type calculation: str
        :param currency: The 3-digit ISO 4217 currency code of the data. If undefined, default is the plan's consolidation currency. If the currency is different from the plan's consolidation currency, the values are converted to the consolidation currency using the conversion rates loaded for the plan's baseline period.
        :type currency: str
        :param method: Sets how to validate the data being loaded into Visier. Valid values:   - **VALIDATE**: Runs a test load through all the validation steps without putting the data into the plan. Use `VALIDATE` to find any errors before using `STRICT_UPLOAD` to load the data.   - **SKIP_ERRORS**: Loads all data without errors into the plan. Any rows with errors are excluded from the plan.   - **STRICT_UPLOAD**: Loads data into the plan if there are no errors in any row. If there are errors, the load fails. This is the default.
        :type method: str
        :param target_tenant_id: Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.
        :type target_tenant_id: str
        :param file: The CSV file to load into the plan.
        :type file: bytearray
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._plan_data_load_plan_data_upload_serialize(
            plan_id=plan_id,
            scenario_id=scenario_id,
            calculation=calculation,
            currency=currency,
            method=method,
            target_tenant_id=target_tenant_id,
            file=file,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PlanDataUploadResponseDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _plan_data_load_plan_data_upload_serialize(
        self,
        plan_id,
        scenario_id,
        calculation,
        currency,
        method,
        target_tenant_id,
        file,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if plan_id is not None:
            _path_params['planId'] = plan_id
        if scenario_id is not None:
            _path_params['scenarioId'] = scenario_id
        if calculation is not None:
            _path_params['calculation'] = calculation
        if currency is not None:
            _path_params['currency'] = currency
        if method is not None:
            _path_params['method'] = method
        # process the query parameters
        # process the header parameters
        if target_tenant_id is not None:
            _header_params['TargetTenantID'] = target_tenant_id
        # process the form parameters
        if file is not None:
            _files['file'] = file
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'multipart/form-data'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'CookieAuth', 
            'ApiKeyAuth', 
            'OAuth2Auth', 
            'OAuth2Auth', 
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='PATCH',
            resource_path='/v1alpha/planning/data/plans/{planId}/scenarios/{scenarioId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def plan_data_load_plan_row_data_load(
        self,
        plan_id: Annotated[StrictStr, Field(description="The unique identifier of the plan.")],
        method: Annotated[Optional[StrictStr], Field(description="Sets how to validate the data being loaded into Visier. Valid values:   - **VALIDATE**: Runs a test load through all the validation steps without putting the data into the plan. Use `VALIDATE` to find any errors before using `STRICT_UPLOAD` to load the data.   - **SKIP_ERRORS**: Loads all data without errors into the plan. Any rows with errors are excluded from the plan.   - **STRICT_UPLOAD**: Loads data into the plan if there are no errors in any row. If there are errors, the load fails. This is the default.")] = None,
        target_tenant_id: Annotated[Optional[StrictStr], Field(description="Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.")] = None,
        file: Annotated[Optional[Union[StrictBytes, StrictStr, Tuple[StrictStr, StrictBytes]]], Field(description="The CSV file to load into the plan.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> PlanRowDataLoadResponseDTO:
        """Add or remove plan rows

        Send a file to Visier to modify a plan's rows. The file must be in CSV format and contain the following columns: - `Add/Remove`: In the column, use the value \"Add\" to add the specified row to the plan or \"Remove\" to remove the specified row from the plan. - A column for each dimension path or `planSegmentLevels` ID.    - If adding rows, use one column per part of the path. For example, to add a new organization under Product, use 3 columns: Organization_Hierarchy.Level_1, Organization_Hierarchy.Level_2, Organization_Hierarchy.Level_3 with 3 segment member values: [Organization_Hierarchy].[Bluesphere], [Organization_Hierarchy].[Product], New Organization.      - If the segment member does not exist, write its display name.     - If the segment member exists, use its `planSegmentLevelMembers` ID. For example, if your plan is segmented by Organization Hierarchy and Location and you want to add a location under your new organization, you would use the columns  Organization_Hierarchy.Level_1, Organization_Hierarchy.Level_2, Organization_Hierarchy.Level_3, Location.Location_1 with the following values: [Organization_Hierarchy].[Bluesphere], [Organization_Hierarchy].[Product], New Organization, [Location].[North America].[United States].   - If removing rows, use one column per plan segment level `segmentId`, where the values are the plan segment levels `id`. To get the IDs, call `GET /v1alpha/planning/model/plans/{id}?withSchema=true`.  <br>**Note:** <em>This API is in **alpha**. While in alpha, APIs may change in a breaking way without notice; functionality may be removed, and no deprecation notices will be issued. If you are interested in using this API, please contact your Customer Success Manager (CSM).</em>

        :param plan_id: The unique identifier of the plan. (required)
        :type plan_id: str
        :param method: Sets how to validate the data being loaded into Visier. Valid values:   - **VALIDATE**: Runs a test load through all the validation steps without putting the data into the plan. Use `VALIDATE` to find any errors before using `STRICT_UPLOAD` to load the data.   - **SKIP_ERRORS**: Loads all data without errors into the plan. Any rows with errors are excluded from the plan.   - **STRICT_UPLOAD**: Loads data into the plan if there are no errors in any row. If there are errors, the load fails. This is the default.
        :type method: str
        :param target_tenant_id: Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.
        :type target_tenant_id: str
        :param file: The CSV file to load into the plan.
        :type file: bytearray
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._plan_data_load_plan_row_data_load_serialize(
            plan_id=plan_id,
            method=method,
            target_tenant_id=target_tenant_id,
            file=file,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PlanRowDataLoadResponseDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            model_package=visier_api_data_in.models,
            response_data=response_data,
            response_types_map=_response_types_map
        ).data


    @validate_call
    def plan_data_load_plan_row_data_load_with_http_info(
        self,
        plan_id: Annotated[StrictStr, Field(description="The unique identifier of the plan.")],
        method: Annotated[Optional[StrictStr], Field(description="Sets how to validate the data being loaded into Visier. Valid values:   - **VALIDATE**: Runs a test load through all the validation steps without putting the data into the plan. Use `VALIDATE` to find any errors before using `STRICT_UPLOAD` to load the data.   - **SKIP_ERRORS**: Loads all data without errors into the plan. Any rows with errors are excluded from the plan.   - **STRICT_UPLOAD**: Loads data into the plan if there are no errors in any row. If there are errors, the load fails. This is the default.")] = None,
        target_tenant_id: Annotated[Optional[StrictStr], Field(description="Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.")] = None,
        file: Annotated[Optional[Union[StrictBytes, StrictStr, Tuple[StrictStr, StrictBytes]]], Field(description="The CSV file to load into the plan.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[PlanRowDataLoadResponseDTO]:
        """Add or remove plan rows

        Send a file to Visier to modify a plan's rows. The file must be in CSV format and contain the following columns: - `Add/Remove`: In the column, use the value \"Add\" to add the specified row to the plan or \"Remove\" to remove the specified row from the plan. - A column for each dimension path or `planSegmentLevels` ID.    - If adding rows, use one column per part of the path. For example, to add a new organization under Product, use 3 columns: Organization_Hierarchy.Level_1, Organization_Hierarchy.Level_2, Organization_Hierarchy.Level_3 with 3 segment member values: [Organization_Hierarchy].[Bluesphere], [Organization_Hierarchy].[Product], New Organization.      - If the segment member does not exist, write its display name.     - If the segment member exists, use its `planSegmentLevelMembers` ID. For example, if your plan is segmented by Organization Hierarchy and Location and you want to add a location under your new organization, you would use the columns  Organization_Hierarchy.Level_1, Organization_Hierarchy.Level_2, Organization_Hierarchy.Level_3, Location.Location_1 with the following values: [Organization_Hierarchy].[Bluesphere], [Organization_Hierarchy].[Product], New Organization, [Location].[North America].[United States].   - If removing rows, use one column per plan segment level `segmentId`, where the values are the plan segment levels `id`. To get the IDs, call `GET /v1alpha/planning/model/plans/{id}?withSchema=true`.  <br>**Note:** <em>This API is in **alpha**. While in alpha, APIs may change in a breaking way without notice; functionality may be removed, and no deprecation notices will be issued. If you are interested in using this API, please contact your Customer Success Manager (CSM).</em>

        :param plan_id: The unique identifier of the plan. (required)
        :type plan_id: str
        :param method: Sets how to validate the data being loaded into Visier. Valid values:   - **VALIDATE**: Runs a test load through all the validation steps without putting the data into the plan. Use `VALIDATE` to find any errors before using `STRICT_UPLOAD` to load the data.   - **SKIP_ERRORS**: Loads all data without errors into the plan. Any rows with errors are excluded from the plan.   - **STRICT_UPLOAD**: Loads data into the plan if there are no errors in any row. If there are errors, the load fails. This is the default.
        :type method: str
        :param target_tenant_id: Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.
        :type target_tenant_id: str
        :param file: The CSV file to load into the plan.
        :type file: bytearray
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._plan_data_load_plan_row_data_load_serialize(
            plan_id=plan_id,
            method=method,
            target_tenant_id=target_tenant_id,
            file=file,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PlanRowDataLoadResponseDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            model_package=visier_api_data_in.models,
            response_data=response_data,
            response_types_map=_response_types_map
        )


    @validate_call
    def plan_data_load_plan_row_data_load_without_preload_content(
        self,
        plan_id: Annotated[StrictStr, Field(description="The unique identifier of the plan.")],
        method: Annotated[Optional[StrictStr], Field(description="Sets how to validate the data being loaded into Visier. Valid values:   - **VALIDATE**: Runs a test load through all the validation steps without putting the data into the plan. Use `VALIDATE` to find any errors before using `STRICT_UPLOAD` to load the data.   - **SKIP_ERRORS**: Loads all data without errors into the plan. Any rows with errors are excluded from the plan.   - **STRICT_UPLOAD**: Loads data into the plan if there are no errors in any row. If there are errors, the load fails. This is the default.")] = None,
        target_tenant_id: Annotated[Optional[StrictStr], Field(description="Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.")] = None,
        file: Annotated[Optional[Union[StrictBytes, StrictStr, Tuple[StrictStr, StrictBytes]]], Field(description="The CSV file to load into the plan.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Add or remove plan rows

        Send a file to Visier to modify a plan's rows. The file must be in CSV format and contain the following columns: - `Add/Remove`: In the column, use the value \"Add\" to add the specified row to the plan or \"Remove\" to remove the specified row from the plan. - A column for each dimension path or `planSegmentLevels` ID.    - If adding rows, use one column per part of the path. For example, to add a new organization under Product, use 3 columns: Organization_Hierarchy.Level_1, Organization_Hierarchy.Level_2, Organization_Hierarchy.Level_3 with 3 segment member values: [Organization_Hierarchy].[Bluesphere], [Organization_Hierarchy].[Product], New Organization.      - If the segment member does not exist, write its display name.     - If the segment member exists, use its `planSegmentLevelMembers` ID. For example, if your plan is segmented by Organization Hierarchy and Location and you want to add a location under your new organization, you would use the columns  Organization_Hierarchy.Level_1, Organization_Hierarchy.Level_2, Organization_Hierarchy.Level_3, Location.Location_1 with the following values: [Organization_Hierarchy].[Bluesphere], [Organization_Hierarchy].[Product], New Organization, [Location].[North America].[United States].   - If removing rows, use one column per plan segment level `segmentId`, where the values are the plan segment levels `id`. To get the IDs, call `GET /v1alpha/planning/model/plans/{id}?withSchema=true`.  <br>**Note:** <em>This API is in **alpha**. While in alpha, APIs may change in a breaking way without notice; functionality may be removed, and no deprecation notices will be issued. If you are interested in using this API, please contact your Customer Success Manager (CSM).</em>

        :param plan_id: The unique identifier of the plan. (required)
        :type plan_id: str
        :param method: Sets how to validate the data being loaded into Visier. Valid values:   - **VALIDATE**: Runs a test load through all the validation steps without putting the data into the plan. Use `VALIDATE` to find any errors before using `STRICT_UPLOAD` to load the data.   - **SKIP_ERRORS**: Loads all data without errors into the plan. Any rows with errors are excluded from the plan.   - **STRICT_UPLOAD**: Loads data into the plan if there are no errors in any row. If there are errors, the load fails. This is the default.
        :type method: str
        :param target_tenant_id: Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.
        :type target_tenant_id: str
        :param file: The CSV file to load into the plan.
        :type file: bytearray
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._plan_data_load_plan_row_data_load_serialize(
            plan_id=plan_id,
            method=method,
            target_tenant_id=target_tenant_id,
            file=file,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PlanRowDataLoadResponseDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _plan_data_load_plan_row_data_load_serialize(
        self,
        plan_id,
        method,
        target_tenant_id,
        file,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if plan_id is not None:
            _path_params['planId'] = plan_id
        if method is not None:
            _path_params['method'] = method
        # process the query parameters
        # process the header parameters
        if target_tenant_id is not None:
            _header_params['TargetTenantID'] = target_tenant_id
        # process the form parameters
        if file is not None:
            _files['file'] = file
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'multipart/form-data'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'CookieAuth', 
            'ApiKeyAuth', 
            'OAuth2Auth', 
            'OAuth2Auth', 
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='PATCH',
            resource_path='/v1alpha/planning/data/plans/{planId}/rows',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Visier Data In APIs

    Visier APIs for sending data to Visier and running data load jobs.

    The version of the OpenAPI document: 22222222.99201.1614
    Contact: alpine@visier.com

    Please note that this SDK is currently in beta.
    Functionality and behavior may change in future releases.
    We encourage you to provide feedback and report any issues encountered during your use.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class StartExtractionModel(BaseModel):
    """
    StartExtractionModel
    """ # noqa: E501
    all_tenants: Optional[StrictBool] = Field(default=None, description="If `true`, one extraction job is dispatched for each accessible analytic tenant. Only valid for requests from an administrating tenant.", alias="allTenants")
    batch_size_override: Optional[StrictInt] = Field(default=None, description="The maximum number of subjects the job can retrieve in each batch.", alias="batchSizeOverride")
    connector_ids: Optional[List[StrictStr]] = Field(default=None, description="The unique identifiers of the connectors to run extraction jobs.", alias="connectorIds")
    data_category_id: Optional[StrictStr] = Field(default=None, description="The unique identifier of the data category on which to trigger the extraction job. Default is the tenant's primary data category.", alias="dataCategoryId")
    disable_artifact_generation: Optional[StrictBool] = Field(default=None, description="If `true`, the job does not generate data load artifacts. If unspecified, the default is `false`.", alias="disableArtifactGeneration")
    excluded_tenants: Optional[List[StrictStr]] = Field(default=None, description="The unique IDs of the tenants to exclude from the extraction job. Only valid if `allTenants` is \"true\". Only valid for requests from an administrating tenant.", alias="excludedTenants")
    extract_to_time_override: Optional[StrictStr] = Field(default=None, description="An epoch timestamp in milliseconds for the end time up to which to retrieve data.", alias="extractToTimeOverride")
    force_update_existing_artifacts: Optional[StrictBool] = Field(default=None, description="If `true` and `disableArtifactGeneration` is `false`, updates extractor artifacts, which may overwrite the artifacts' manual overrides. Ignored if `disableArtifactGeneration` is `true`.", alias="forceUpdateExistingArtifacts")
    last_extraction_time_offset_weeks: Optional[StrictInt] = Field(default=None, description="The number of weeks in the past to retrieve data. This overrides the last extraction date to retrieve more data.", alias="lastExtractionTimeOffsetWeeks")
    months_to_extract: Optional[StrictInt] = Field(default=None, description="The number of months to retrieve snapshot data.", alias="monthsToExtract")
    override_last_extraction_timestamp: Optional[StrictStr] = Field(default=None, description="The time from which to extract data.", alias="overrideLastExtractionTimestamp")
    publish_data_load_artifacts: Optional[StrictBool] = Field(default=None, description="If `true`, the generated data load artifacts are published to production immediately.", alias="publishDataLoadArtifacts")
    run_processing_job: Optional[StrictBool] = Field(default=None, description="If `true`, a processing job is spawned after a dispatched extraction job runs successfully.", alias="runProcessingJob")
    sql_batch_size: Optional[StrictInt] = Field(default=None, description="The maximum amount of SQL table records the job can retrieve in each batch.", alias="sqlBatchSize")
    tenants: Optional[List[StrictStr]] = Field(default=None, description="A list of analytic tenants to dispatch extraction jobs for. One extraction job is dispatched per tenant. Only valid for requests from an administrating tenant.")
    __properties: ClassVar[List[str]] = ["allTenants", "batchSizeOverride", "connectorIds", "dataCategoryId", "disableArtifactGeneration", "excludedTenants", "extractToTimeOverride", "forceUpdateExistingArtifacts", "lastExtractionTimeOffsetWeeks", "monthsToExtract", "overrideLastExtractionTimestamp", "publishDataLoadArtifacts", "runProcessingJob", "sqlBatchSize", "tenants"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of StartExtractionModel from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of StartExtractionModel from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "allTenants": obj.get("allTenants"),
            "batchSizeOverride": obj.get("batchSizeOverride"),
            "connectorIds": obj.get("connectorIds"),
            "dataCategoryId": obj.get("dataCategoryId"),
            "disableArtifactGeneration": obj.get("disableArtifactGeneration"),
            "excludedTenants": obj.get("excludedTenants"),
            "extractToTimeOverride": obj.get("extractToTimeOverride"),
            "forceUpdateExistingArtifacts": obj.get("forceUpdateExistingArtifacts"),
            "lastExtractionTimeOffsetWeeks": obj.get("lastExtractionTimeOffsetWeeks"),
            "monthsToExtract": obj.get("monthsToExtract"),
            "overrideLastExtractionTimestamp": obj.get("overrideLastExtractionTimestamp"),
            "publishDataLoadArtifacts": obj.get("publishDataLoadArtifacts"),
            "runProcessingJob": obj.get("runProcessingJob"),
            "sqlBatchSize": obj.get("sqlBatchSize"),
            "tenants": obj.get("tenants")
        })
        return _obj





# coding: utf-8

"""
    Visier Data In APIs

    Visier APIs for sending data to Visier and running data load jobs.

    The version of the OpenAPI document: 22222222.99201.1614
    Contact: alpine@visier.com

    Please note that this SDK is currently in beta.
    Functionality and behavior may change in future releases.
    We encourage you to provide feedback and report any issues encountered during your use.
"""  # noqa: E501


import unittest

from visier_api_data_in.api.pgp_key_api import PGPKeyApi


class TestPGPKeyApi(unittest.TestCase):
    """PGPKeyApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PGPKeyApi()

    def tearDown(self) -> None:
        pass

    def test_delete_pgp_key_pair(self) -> None:
        """Test case for delete_pgp_key_pair

        Delete a PGP key pair
        """
        pass

    def test_generate_pgp_key_pair(self) -> None:
        """Test case for generate_pgp_key_pair

        Download a public encryption key
        """
        pass

    def test_get_all_pgp_public_keys(self) -> None:
        """Test case for get_all_pgp_public_keys

        Retrieve all PGP public keys
        """
        pass

    def test_get_pgp_public_key(self) -> None:
        """Test case for get_pgp_public_key

        Retrieve a PGP public key using the key ID
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Visier Data In APIs

    Visier APIs for sending data to Visier and running data load jobs.

    The version of the OpenAPI document: 22222222.99201.1614
    Contact: alpine@visier.com

    Please note that this SDK is currently in beta.
    Functionality and behavior may change in future releases.
    We encourage you to provide feedback and report any issues encountered during your use.
"""  # noqa: E501


import unittest

from visier_api_data_in.api.planning_data_load_api import PlanningDataLoadApi


class TestPlanningDataLoadApi(unittest.TestCase):
    """PlanningDataLoadApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PlanningDataLoadApi()

    def tearDown(self) -> None:
        pass

    def test_plan_data_load_plan_data_upload(self) -> None:
        """Test case for plan_data_load_plan_data_upload

        Upload plan data
        """
        pass

    def test_plan_data_load_plan_row_data_load(self) -> None:
        """Test case for plan_data_load_plan_row_data_load

        Add or remove plan rows
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Visier Data In APIs

    Visier APIs for sending data to Visier and running data load jobs.

    The version of the OpenAPI document: 22222222.99201.1614
    Contact: alpine@visier.com

    Please note that this SDK is currently in beta.
    Functionality and behavior may change in future releases.
    We encourage you to provide feedback and report any issues encountered during your use.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class KeyPairDeleteResponseDTO(BaseModel):
    """
    KeyPairDeleteResponseDTO
    """ # noqa: E501
    key_id: Optional[StrictStr] = Field(default=None, description="The key ID in 16-letter hexadecimal format, including leading zeros.", alias="keyID")
    __properties: ClassVar[List[str]] = ["keyID"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of KeyPairDeleteResponseDTO from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of KeyPairDeleteResponseDTO from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "keyID": obj.get("keyID")
        })
        return _obj


